pub trait GraphData { }Expand description
Marker trait for algorithms that work with graph data
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
pub trait GraphData { }Marker trait for algorithms that work with graph data
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".