pub trait TextData { }Expand description
Marker trait for algorithms that work with text data
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
pub trait TextData { }Marker trait for algorithms that work with text data
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".